@@ -97,16 +97,16 @@ static void GotoPage(int page)
 	if (!gs_ready)
 		return;
 
-	if (page == gs_page)
-	{
-		/* Excellent - the page that GhostScript just rendered is
-		 * the one the user wants */
-	}
-	else if (page == prev_page)
+	if (page == prev_page)
 	{
 		/* Still have this page cached */
 		XCopyArea(display, prev_pix, draw_pix, gc, 0, 0, width, height, 0, 0);
 	}
+	else if (page == gs_page)
+	{
+		/* Excellent - the page that GhostScript just rendered is
+		 * the one the user wants */
+	}
 	else
 	{
 		RenderPage(page);
